from setuptools import setup

setup(
    name="hazelib",
    version="0.0.14",
    packages=["hazelib"],
    description='My utility package.',
    url='http://github.com/hazelpy/hazelib',
    author='Hazelpy',
    author_email='hazelpytv@gmail.com',
    license='MIT',
    zip_safe=False)
